/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "newtMenu.h"
#include "../variousEntities/rectangle.h"



NewtMenu::NewtMenu(wstring title, Vector3 center, Vector3 rotAxis, float angle):
EntityWithPosition(center, rotAxis, angle), mSelectedMenuItem(-1), mTitle(title) {
	
	mNumClick = -1;
	
}

NewtMenu::~NewtMenu() {
	
}
		
void NewtMenu::setMenuItems(std::vector<wstring> menuNames, int numTextColor, float numTextColorCoeff, int numBackgroundColor, float backgroundColorCoeff, float width, float height) {
	
	mCenter.y += ((float ) menuNames.size() -2.)/ 2. * height * 1.2;
	
	
	Mesh *meshTitle = new RectangleMesh(width, 1, height, 1);
	 
	Material *materialTitle = new Material("menuTitle", numTextColor);
	materialTitle->addTexture(mTitle, numTextColor, numTextColorCoeff, numBackgroundColor, backgroundColorCoeff*0.8, COLOR_MAP, 512, 64, GL_CLAMP, false);	
	
	addChild(new EntityWithPosition(materialTitle, meshTitle, true, 
									Vector3(0., height * 1.5, 0.), Vector3(0.,1.,0.), 0.));
	
	
	NewtMenuItem *menuItem;
	
	for(int i=0;i<menuNames.size();i++) {
		menuItem = new NewtMenuItem(menuNames[i], numTextColor, numTextColorCoeff, numBackgroundColor, backgroundColorCoeff, width, height, i);
		menuItem->setNumClick(i);
		addChild(menuItem,i);
	}
}
		
int NewtMenu::getSelectedMenuItem() {
	return mSelectedMenuItem;
}

void NewtMenu::selectMenuItem(int numMenuItem) {
	
	
	mSelectedMenuItem = numMenuItem;
}

/****************************/
/*	NewtMenuItem			*/
/****************************/

NewtMenuItem::NewtMenuItem(wstring name, int textColor, float textColorCoeff, int numBackgroundColor, float backgroundColorCoeff, float width, float height, int position) :
Entity()
 {
	mPosition = Vector3(0., -(float) position * height * 1.2, 0.);

	Mesh *mesh = new RectangleMesh(width, 1, height, 1);
	setMesh(mesh);
	 
	Material *material = new Material("menuMaterial", textColor);
	material->addTexture(name, textColor, textColorCoeff, numBackgroundColor, backgroundColorCoeff, COLOR_MAP, 512, 64, GL_CLAMP, false);
	setMaterial(material);
}



NewtMenuItem::~NewtMenuItem() {
}
	
void NewtMenuItem::applyTransformation() {
	glTranslatef (mPosition.x, mPosition.y, mPosition.z);
}




