/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2008, 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "rectangle.h"


RectangleMesh::RectangleMesh(float dim1, int nb1, float dim2, int nb2) :
	Mesh("rectangle", false, false, false, false), mDim1(dim1), mNb1(nb1), mDim2(dim2), mNb2(nb2), 
	mTexBegin1(0.), mTexEnd1(1.),mTexBegin2(0.), mTexEnd2(1.) {
}

RectangleMesh::RectangleMesh(float dim1, int nb1, float texOffset1, float dim2, int nb2, float texOffset2) :
	Mesh("rectangle", false, false, false, false), mDim1(dim1), mNb1(nb1), mDim2(dim2), mNb2(nb2), 
	mTexBegin1(texOffset1), mTexEnd1(1.-texOffset1),mTexBegin2(texOffset2), mTexEnd2(1.-texOffset2){
	}

RectangleMesh::RectangleMesh(float dim1, int nb1, float texBegin1, float texEnd1, float dim2, int nb2, float texBegin2, float texEnd2):
	Mesh("rectangle", false, false, false, false), mDim1(dim1), mNb1(nb1), mDim2(dim2), mNb2(nb2), 
	mTexBegin1(texBegin1), mTexEnd1(texEnd1),mTexBegin2(texBegin2), mTexEnd2(texEnd2){
	}
	
	
RectangleMesh::~RectangleMesh() {
}

void RectangleMesh::initFirstParams() {
	
	geometry.nbVertices = (mNb1+1) * (mNb2+1);
	
	geometry.nbIndexArrays = mNb1;
	geometry.primType = new GLenum[mNb1];
	for(int i=0;i<mNb1;i++) {
		geometry.primType[i] = GL_QUAD_STRIP;
	}
	
	geometry.nbIndices = new int[mNb1];
	for(int i=0;i<mNb1;i++) {
		geometry.nbIndices[i] = 2 * (mNb2+1);
	}	
		
	mpUniformNormal = new Vector3(0., 0., 1.);
	mpUniformTangent = new Vector3(1., 0., 0.);
}

void RectangleMesh::createVertices(Vector3 *ptr) {
	for(int i=0;i<=mNb1;i++) {
		for(int j=0;j<=mNb2;j++){
			*ptr = Vector3(mDim1*((GLfloat) i/mNb1-1./2.),mDim2*((GLfloat) j/mNb2-1./2.),0);
	    	ptr ++;
		}
	}
}

void RectangleMesh::createColors(Color *ptr) {
	//no color per vertex for a rectangle
}

void RectangleMesh::createNormals(Vector3 *ptr) {
	// better use the uniform normal for a rectangle
}

void RectangleMesh::createTexCoords(GLfloat *ptr) {
	for(int i=0;i<mNb1+1;i++){
		for(int j=0;j<mNb2+1;j++){
			*ptr = mTexBegin1 + (GLfloat) i/mNb1 * (mTexEnd1 - mTexBegin1);
	    	ptr ++;
			*ptr = mTexBegin2 + (GLfloat) j/mNb2 * (mTexEnd2 - mTexBegin2);
	    	ptr ++;			
		}
	}		
}

void RectangleMesh::createFogCoords(GLfloat *ptr) {
	// TODO ?
}

void RectangleMesh::createTangents(Vector3 *ptr) {
	// better use the uniform normal for a rectangle	
}


void RectangleMesh::createIndices(int numArray, GLuint *ptr) {

	for(int j=0;j<=mNb2;j++){
		*ptr = numArray*(mNb2+1) + j;
		ptr++;
		*ptr = (numArray +1)*(mNb2+1) + j;
		ptr++;		
	}
}



